@@ -69,6 +69,8 @@ ROC = "roc"
 F1_SCORE = 'f1_score'
 CONFUSION_MAT = 'confusion_mat'
 PSI = 'psi'
+VIF = 'vif'
+PEARSON = 'pearson'
 FEATURE_IMPORTANCE = 'feature_importance'
 QUANTILE_PR = 'quantile_pr'
 JACCARD_SIMILARITY_SCORE = 'jaccard_similarity_score'
@@ -204,6 +206,8 @@ SECURE_AGG_AMPLIFY_FACTOR = 1000
 QUANTILE = 'quantile'
 BUCKET = 'bucket'
 OPTIMAL = 'optimal'
+VIRTUAL_SUMMARY = 'virtual_summary'
+RECURSIVE_QUERY = 'recursive_query'
 
 # Feature selection methods
 UNIQUE_VALUE = 'unique_value'
@@ -218,6 +222,8 @@ PERCENTAGE_VALUE = 'percentage_value'
 IV_FILTER = 'iv_filter'
 STATISTIC_FILTER = 'statistic_filter'
 PSI_FILTER = 'psi_filter'
+VIF_FILTER = 'vif_filter'
+CORRELATION_FILTER = 'correlation_filter'
 HETERO_SBT_FILTER = 'hetero_sbt_filter'
 HOMO_SBT_FILTER = 'homo_sbt_filter'
 HETERO_FAST_SBT_FILTER = 'hetero_fast_sbt_filter'
@@ -282,3 +288,11 @@ MANUAL = 'manual'
 
 # scorecard
 CREDIT = 'credit'
+
+# sample weight
+BALANCED = 'balanced'
+
+MAX_SAMPLE_OUTPUT_LIMIT = 10 ** 6
+
+# Hetero NN Selective BP Strategy
+SELECTIVE_SIZE = 1024
